@@ -2,11 +2,11 @@ package Bio::Phylo::Treedrawer::Pdf;
 use strict;
 use base 'Bio::Phylo::Treedrawer::Abstract';
 use Bio::Phylo::Util::Exceptions 'throw';
-use Bio::Phylo::Util::CONSTANT 'looks_like_hash';
+use Bio::Phylo::Util::CONSTANT qw'looks_like_hash _PI_';
 use Bio::Phylo::Util::Dependency qw'PDF::API2::Lite PDF::API2::Annotation';
 use Bio::Phylo::Util::Logger;
 my $logger = Bio::Phylo::Util::Logger->new;
-my $PI     = '3.14159265358979323846';
+my $PI     = _PI_;
 my %colors;
 
 =head1 NAME
@@ -56,7 +56,12 @@ sub _new {
 sub _finish {
     $logger->debug("finishing drawing");
     my $self = shift;
-    $self->_api->saveas('file.pdf');
+    require File::Temp;
+    my ( $fh, $filename ) = File::Temp::tempfile();
+    $self->_api->saveas($filename);
+    my $result = do { local $/; <$fh> };
+    unlink $filename;
+    return $result;
 }
 
 =begin comment
@@ -89,6 +94,57 @@ sub _draw_curve {
 
 =begin comment
 
+# -x1 => $x1,
+# -x2 => $x2,
+# -y1 => $y1,
+# -y2 => $y2,
+# -radius => $radius
+# -width => $width,
+# -color => $color
+
+=end comment
+
+=cut
+
+sub _draw_arc {    
+    my $self = shift;
+    my $drawer = $self->_drawer;
+    my %args = @_;
+    my @keys = qw(-x1 -y1 -x2 -y2 -radius -width -color);
+    my ( $x1, $y1, $x2, $y2, $radius, $linewidth, $color ) = @args{@keys};    
+    
+    # calculate center
+    my $height = $drawer->get_height;
+    my $width  = $drawer->get_width;
+    my $cx = $width / 2;
+    my $cy = $height / 2;
+    
+    # compute start and end
+    my ( $r1, $start ) = $drawer->cartesian_to_polar( $x1 - $cx, $y1 - $cy );
+    my ( $r2, $end )   = $drawer->cartesian_to_polar( $x2 - $cx, $y2 - $cy );
+    $start += 360 if $start < 0;
+    $end   += 360 if $end < 0;
+    
+    # rotations in PDF are counter-clockwise, so need to be "inverted"
+    $start = ( $start - 360 ) * - 1;
+    $start -= 360 if $start > 360;
+    
+    $end = ( $end - 360 ) * - 1;
+    $end -= 360 if $end > 360;        
+    
+    $logger->debug("drawing arc cx:$cx cy:$cy radius:$radius start:$start end:$end");
+    
+    if ( $start != $end ) {
+        return $self->_api->linewidth( $linewidth || 1 )
+          ->strokecolor( $color ? "#$color" : "#000000" )
+          ->move( $x1, $cy + ( $cy - $y1 ) )
+          ->arc( $cx, $cy, $radius, $radius, $start, $end )
+          ->stroke();
+    }
+}
+
+=begin comment
+
 # required:
 # -x1 => $x1,
 # -y1 => $y1,
@@ -196,20 +252,26 @@ sub _draw_multi {
 
 =cut
 
-sub _draw_text {
-    $logger->debug("drawing text");
+sub _draw_text {    
     my $self = shift;
     if ( not $self->{'FONT'} ) {
         $self->{'FONT'} = $self->_api->corefont('Times-Roman');
     }
     my %args = @_;
-    my ( $x, $y, $text, $url, $size ) = @args{qw(-x -y -text -url -size)};
+    my ( $x, $y, $text, $url, $size, $rotation ) = @args{qw(-x -y -text -url -size -rotation)};
     if ($url) {
         $logger->warn( ref($self) . " can't embed links, yet" );
     }
     my $height = $self->_drawer->get_height;
+    
+    # rotations in PDF are counter-clockwise, so need to be "inverted"
+    my $angle = ( $rotation->[0] - 360 ) * - 1;
+    $angle -= 360 if $angle > 360;;
+    
+    $logger->debug("drawing text $text - $angle");
+    
     return $self->_api->fillcolor("#000000")
-      ->print( $self->{'FONT'}, $size || 12, $x, $height - $y, 0, 0, $text, );
+      ->print( $self->{'FONT'}, $size || 12, $rotation->[1], $height - $rotation->[2], $angle, 0, $text, );
 }
 
 =begin comment
